Polynomial

Struct Polynomial 

pub struct Polynomial { /* private fields */ }
A polynomial over the ML-KEM ring. Dev note: this doesn’t strictly need to be pub … ie there’s no good reason for a caller to use this class directly, but in order to test the Debug and Display traits, you need STD, so those can’t be tested from inline tests in this file and the real unit tests are in a different crate, so here we are.

Implementations

Source

impl Polynomial

pub const fn new() -> Self

Create a new polynomial with all coefficients set to zero.